==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextUI__24UpdateHandler.h <==
// class javax.swing.plaf.basic.BasicTextUI$UpdateHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c478fc0ba7b82ad9 javax_swing_plaf_basic_BasicTextUI__24UpdateHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTextUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method$_init$7d9c801be3d1d113(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTextUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTextUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24UpdateHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextUI__24UpdateHandler.h <==
// class javax.swing.plaf.basic.BasicTextUI$UpdateHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c478fc0ba7b82ad9 javax_swing_plaf_basic_BasicTextUI__24UpdateHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTextUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method$_init$7d9c801be3d1d113(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTextUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vmethods	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTextUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_refs	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24UpdateHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24UpdateHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24UpdateHandler_H_ */
